const path = require('path');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
const IgnoreEmitPlugin = require('ignore-emit-webpack-plugin');

module.exports = {
  entry: {
    // Entry for your CSS file(s)
    style1: './includes/affiliate-signup-widget/template/index.js',
  },
  output: {
    // Output configuration
    filename: (chunkData) => {
      return chunkData.chunk.name === 'main' ? 'dist/[name].js' : '[name]/[name].js';
    },
  },
  module: {
    // Rules for how to handle different modules
    rules: [
      {
        test: /\.css$/,
        use: [
          MiniCssExtractPlugin.loader,
          'css-loader',
          'postcss-loader',
        ],
      },
    ],
  },
  optimization: {
    // Optimization configuration for minimization
    minimizer: [
      new CssMinimizerPlugin(), // Add the CssMinimizerPlugin for CSS
    ],
  },
  plugins: [
    // Plugins configuration
    new MiniCssExtractPlugin({
      filename: (chunkData) => {
        // Logic for determining the output file name based on the mode
        let name = chunkData.chunk.name === 'main' ? 'dist/styles' : 'affiliate-signup-widget';
        if (process.env.NODE_ENV === 'production') {
          name += '.min.css'; // Suffix for production mode
        } else {
          name += '.css'; // Suffix for other modes like development
        }
        return `../assets/css/${name}`; // Adjust the path as needed
      },
    }),
    new IgnoreEmitPlugin(['style1.js']), // Plugin to ignore the unwanted JS output
  ],
};
